# SzEngineGetStatsResponse

{
"workload": {
"apiVersion": "string",
"caches": {
"libFeatCacheHit": "int32",
"libFeatCacheMiss": "int32",
"libFeatInsert": "int32",
"resFeatStatCacheHit": "int32",
"resFeatStatCacheMiss": "int32",
"resFeatStatInsert": "int32",
"resFeatStatUpdateAttempt": "int32",
"resFeatStatUpdateFail": "int32"
},
"candidates": {
"candidateBuilders": {
"user_defined_json_key": "int32"
},
"suppressedCandidateBuilders": {
"user_defined_json_key": "int32"
}
},
"contention": {
"feature": {
"FIXME_KEY": "string"
},
"resEnt": {
"FIXME_KEY": "string"
},
"valuelatch": {
"FIXME_KEY": "string"
}
},
"datetimestamp": "string",
"expressedFeatures": {
"calls": [
{
"EFCALL_ID": "int32",
"EFUNC_CODE": "string",
"numCalls": "int32"
}
],
"created": {
"user_defined_json_key": "int32"
}
},
"genericDetect": {
"FIXME_KEY": "string"
},
"license": {
"dsrLimit": "string",
"status": "string",
"type": "string"
},
"loadedRecords": "int32",
"lockWaits": {
"refreshLocks": {
"count": "int32",
"maxMS": "int32",
"totalMS": "int32"
}
},
"processing": {
"addedRecords": "int32",
"ambiguous": {
"actualTest": "int32",
"cachedTest": "int32"
},
"batchAddedRecords": "int32",
"deletedRecords": "int32",
"details": {
"addedRecords": "int32",
"candidates": "int32",
"changeDeletes": "int32",
"duration": "int32",
"filteredObsFeat": "int32",
"newObsEnt": "int32",
"obsEntHashDiff": "int32",
"obsEntHashSame": "int32",
"optimizedOut": "int32",
"optimizedOutSkipped": "int32",
"partiallyResolved": "int32",
"retries": "int32"
},
"reevaluations": "int32",
"repairedEntities": "int32"
},
"redoTriggers": {
"user_defined_json_key": "int32"
},
"repairDiagnosis": {
"types": "int32"
},
"reresolve": {
"newFeatureFTypes": {
"user_defined_json_key": "int32"
},
"suppressedCandidateBuildersForReresolve": {
"FIXME_KEY": "string"
},
"suppressedScoredFeatureTypeForReresolve": {
"FIXME_KEY": "string"
},
"triggers": {
"abortRetry": "int32",
"multipleResolvableCandidates": "int32",
"resolveNewFeatures": "int32",
"skipped": "int32",
"unresolveMovement": "int32"
}
},
"scoring": {
"cacheHit": {
"user_defined_json_key": "int32"
},
"cacheMiss": {
"user_defined_json_key": "int32"
},
"scoredPairs": {
"user_defined_json_key": "int32"
},
"suppressedDisclosedRelationshipDomainCount": "int32",
"suppressedScoredFeatureType": {
"FIXME_KEY": "string"
}
},
"systemResources": {
"currResources": {
"activeThreads": "int32",
"availableMemory": "string",
"processMemory": "string",
"workerThreads": "int32"
},
"initResources": {
"XXX_physicalCores": "int32",
"availableMemory": "string",
"logicalCores": "int32",
"totalMemory": "string"
},
"systemLoad": {
"cpuIdle": "string",
"cpuSystem": "string",
"cpuUser": "string",
"cpuWait": "string"
}
},
"threadState": {
"active": "int32",
"dataLatchContention": "int32",
"governorContention": "int32",
"idle": "int32",
"loader": "int32",
"obsEntContention": "int32",
"resEntContention": "int32",
"resolver": "int32",
"scoring": "int32",
"sqlExecuting": "int32"
},
"unresolve": {
"abortedUnresolve": "int32",
"triggers": {
"ambiguousMultiResolve": "int32",
"ambiguousNoResolve": "int32",
"extensiveResolve": "int32",
"normalResolve": "int32",
"relLink": "int32",
"update": "int32"
},
"unresolveTest": "int32"
}
}
}